%define enable_tests	0

%define major		8
%define libname		%mklibname gearman %{major}
%define develname	%mklibname gearman -d

Name:		gearmand
Version:	1.1.21
Release:	%mkrel 4
Summary:	Gearman Server and C Library
License:	BSD
Group:		System/Servers
URL:		https://gearman.org/
Source0:	https://github.com/gearman/gearmand/releases/download/%{version}/%{name}-%{version}.tar.gz
Source1:	gearmand.service
Source2:	gearmand.sysconfig
Source3:	gearmand.logrotate
BuildRequires:	doxygen
BuildRequires:	gperf
BuildRequires:	memcached
BuildRequires:	valgrind
BuildRequires:	boost-devel
BuildRequires:	libdrizzle-devel >= 5.1
BuildRequires:	lzmalib-devel
BuildRequires:	mysql-devel
BuildRequires:	pkgconfig(hiredis)
BuildRequires:	pkgconfig(libpq) >= 9.3
BuildRequires:	pkgconfig(libcurl)
BuildRequires:	pkgconfig(ext2fs)
BuildRequires:	pkgconfig(libevent)
BuildRequires:	pkgconfig(libmemcached) >= 1.0
BuildRequires:	pkgconfig(uuid)
BuildRequires:	pkgconfig(openssl)
BuildRequires:	pkgconfig(sqlite3)
BuildRequires:	pkgconfig(tokyocabinet)
BuildRequires:	pkgconfig(valgrind)

Requires(post):	systemd >= %{systemd_required_version}
Requires(post):	rpm-helper
Requires(preun):rpm-helper
Requires(pre):	rpm-helper
Requires(postun):rpm-helper

%description
Gearman provides a generic framework to farm out work to other machines,
dispatching function calls to machines that are better suited to do work, to do
work in parallel, to load balance processing, or to call functions between
languages.

%package -n	%{libname}
Summary:	Shared Gearman Client Library
Group:		System/Libraries

%description -n	%{libname}
Gearman provides a generic framework to farm out work to other machines,
dispatching function calls to machines that are better suited to do work, to do
work in parallel, to load balance processing, or to call functions between
languages.

This package contains the Client Library.


%package -n	%{develname}
Summary:	Development files for the Gearman Server and C Library
Group:		Development/C
Requires:	%{libname} = %{version}-%{release}
Provides:	gearman-devel = %{version}-%{release}

%description -n	%{develname}
Development files for the Gearman Server and C Library.


%prep
%setup -q

# fix version
sed -i -e 's/VERSION_NUMBER/[%{version}]/g' configure.ac

%build
autoreconf -fi
%configure \
	--disable-static
%make_build

%install
%make_install

# don't fiddle with the initscript!
export DONT_GPRINTIFY=1

install -d %{buildroot}%{_unitdir}
install -d %{buildroot}%{_sysconfdir}/sysconfig
install -d %{buildroot}%{_sysconfdir}/logrotate.d
install -d %{buildroot}/var/log/%{name}

install -m0755 %{SOURCE1} %{buildroot}%{_unitdir}
install -m0644 %{SOURCE2} %{buildroot}%{_sysconfdir}/sysconfig/%{name}
install -m0644 %{SOURCE3} %{buildroot}%{_sysconfdir}/logrotate.d/%{name}

touch %{buildroot}/var/log/%{name}/gearmand.log

mkdir -p %{buildroot}%{_tmpfilesdir}
cat <<EOF > %{buildroot}%{_tmpfilesdir}/%{name}.conf
d /run/gearmand 0711 gearmand gearmand
EOF

%if %{enable_tests}
%check
make check
%endif

%pre
%_pre_useradd %{name} /dev/null /bin/false

%postun
%_postun_userdel %{name}

%post
%_tmpfilescreate %{name}
%create_ghostfile /var/log/%{name}/gearmand.log %{name} %{name} 0640
%_post_service %{name}

%preun
%_preun_service %{name}

%files
%doc AUTHORS ChangeLog CONTRIBUTING.md README.md THANKS
%license COPYING
%{_unitdir}/%{name}.service
%config(noreplace) %{_sysconfdir}/sysconfig/%{name}
%config(noreplace) %{_sysconfdir}/logrotate.d/%{name}
%{_tmpfilesdir}/%{name}.conf
%{_bindir}/gearadmin
%{_bindir}/gearman
%{_sbindir}/%{name}
%{_mandir}/man1/gear*.1.*
%{_mandir}/man8/gear*.8.*
%attr(0711,%{name},%{name}) %dir /var/log/%{name}
%ghost %attr(0640,%{name},%{name}) /var/log/%{name}/gearmand.log

%files -n %{libname}
%doc AUTHORS ChangeLog CONTRIBUTING.md README.md THANKS
%license COPYING
%{_libdir}/lib*.so.%{major}{,.*}

%files -n %{develname}
%{_includedir}/libgearman/
%{_includedir}/libgearman-1.0/
%{_libdir}/lib*.so
%{_libdir}/pkgconfig/%{name}.pc
%{_mandir}/man3/gear*.3.*
%{_mandir}/man3/libgearman.3.*


%changelog
* Wed Jun 19 2024 wally <wally> 1.1.21-4.mga10
+ Revision: 2075336
- rebuild for boost 1.85.0

* Fri Mar 29 2024 daviddavid <daviddavid> 1.1.21-3.mga10
+ Revision: 2053084
- enable hiredis support

* Fri Jan 12 2024 wally <wally> 1.1.21-2.mga10
+ Revision: 2030533
- rebuild for boost 1.84.0

* Thu Dec 07 2023 daviddavid <daviddavid> 1.1.21-1.mga10
+ Revision: 2014343
- new version: 1.1.21

* Wed Sep 27 2023 wally <wally> 1.1.20-3.mga10
+ Revision: 1991438
- rebuild for boost 1.83.0

* Sat Dec 24 2022 wally <wally> 1.1.20-2.mga9
+ Revision: 1926471
- rebuild for boost 1.81.0

* Wed Dec 14 2022 daviddavid <daviddavid> 1.1.20-1.mga9
+ Revision: 1922009
- new version: 1.1.20

* Sun Jul 03 2022 wally <wally> 1.1.19.1-10.mga9
+ Revision: 1867249
- rebuild for boost 1.79.0

* Sat Apr 02 2022 umeabot <umeabot> 1.1.19.1-9.mga9
+ Revision: 1841181
- Mageia 9 Mass Rebuild

* Sun Dec 19 2021 wally <wally> 1.1.19.1-8.mga9
+ Revision: 1762680
- rebuild for boost 1.78.0

* Sat Sep 11 2021 wally <wally> 1.1.19.1-7.mga9
+ Revision: 1745154
- fix RPATH issue
- let post %%install scriptlet remove .la files
- rebuild for boost 1.77.0

* Fri May 14 2021 wally <wally> 1.1.19.1-5.mga9
+ Revision: 1722960
- rebuild for boost 1.76.0

* Thu Dec 31 2020 wally <wally> 1.1.19.1-4.mga8
+ Revision: 1666758
- rebuild for boost 1.75.0

* Sun Dec 20 2020 wally <wally> 1.1.19.1-3.mga8
+ Revision: 1662000
- rebuild for boost 1.74.0

* Sun May 03 2020 wally <wally> 1.1.19.1-2.mga8
+ Revision: 1578053
- rebuild for boost 1.73.0

* Fri Feb 21 2020 daviddavid <daviddavid> 1.1.19.1-1.mga8
+ Revision: 1548824
- new version: 1.1.19.1

* Wed Feb 19 2020 umeabot <umeabot> 1.1.18-5.mga8
+ Revision: 1544748
- Mageia 8 Mass Rebuild

* Sun Jan 26 2020 wally <wally> 1.1.18-4.mga8
+ Revision: 1483368
- rebuild for boost 1.72.0
- replace deprecated %%configure2_5x

* Tue Oct 16 2018 wally <wally> 1.1.18-3.mga7
+ Revision: 1321034
- rebuild for new boost 1.68.0

* Sun Sep 23 2018 umeabot <umeabot> 1.1.18-2.mga7
+ Revision: 1297850
- Mageia 7 Mass Rebuild

* Sun Jan 28 2018 daviddavid <daviddavid> 1.1.18-1.mga7
+ Revision: 1197739
- new version: 1.1.18

* Mon Dec 25 2017 wally <wally> 1.1.17-5.mga7
+ Revision: 1184748
- rebuild for new boost

* Sat Dec 23 2017 wally <wally> 1.1.17-4.mga7
+ Revision: 1184224
- rebuild for new mariadb

* Tue Nov 21 2017 tv <tv> 1.1.17-3.mga7
+ Revision: 1178319
- rebuild for boost 1.65

* Sat Sep 23 2017 daviddavid <daviddavid> 1.1.17-2.mga7
+ Revision: 1158133
- rebuild for new boost 1.64.0

* Tue Aug 15 2017 daviddavid <daviddavid> 1.1.17-1.mga7
+ Revision: 1140791
- new version: 1.1.17

* Mon Feb 13 2017 mrambo3501 <mrambo3501> 1.1.14-2.mga6
+ Revision: 1085928
- rebuild for new libevent

* Wed Feb 01 2017 daviddavid <daviddavid> 1.1.14-1.mga6
+ Revision: 1084529
- new version: 1.1.14
- update URL and Source URL

* Sun Feb 28 2016 oden <oden> 1.1.12-10.mga6
+ Revision: 980340
- rebuilt for postgresql 9.5.x

* Sun Feb 14 2016 umeabot <umeabot> 1.1.12-9.mga6
+ Revision: 960267
- Mageia 6 Mass Rebuild

* Sat Dec 26 2015 daviddavid <daviddavid> 1.1.12-8.mga6
+ Revision: 915177
- rebuild for new boost 1.60.0

* Fri Sep 25 2015 daviddavid <daviddavid> 1.1.12-7.mga6
+ Revision: 883708
- rebuild for new boost 1.59.0

* Mon Aug 31 2015 cjw <cjw> 1.1.12-6.mga6
+ Revision: 871460
- rebuild with gcc 5

* Fri Jul 31 2015 daviddavid <daviddavid> 1.1.12-5.mga6
+ Revision: 860010
- rebuild for new boost-1.58.0

* Tue Nov 25 2014 cjw <cjw> 1.1.12-4.mga5
+ Revision: 798948
- rebuild against postgresql9.4

* Wed Oct 15 2014 umeabot <umeabot> 1.1.12-3.mga5
+ Revision: 751141
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.1.12-2.mga5
+ Revision: 679470
- Mageia 5 Mass Rebuild

* Fri Aug 22 2014 daviddavid <daviddavid> 1.1.12-1.mga5
+ Revision: 666456
- switch BRs to pkgconfig
- add BRs valgrind and valgrind-devel
- new version: 1.1.12

* Sat Feb 08 2014 barjac <barjac> 1.1.8-5.mga5
+ Revision: 586522
- rebuild against boost-1.55

* Mon Dec 02 2013 colin <colin> 1.1.8-4.mga4
+ Revision: 554629
- Fix systemd unit and sysconfig files.

* Sat Oct 19 2013 umeabot <umeabot> 1.1.8-3.mga4
+ Revision: 529444
- Mageia 4 Mass Rebuild

* Tue Jul 09 2013 fwang <fwang> 1.1.8-2.mga4
+ Revision: 451855
- rebuild for new boost

* Thu Jun 13 2013 oden <oden> 1.1.8-1.mga4
+ Revision: 442837
- 1.1.8

* Wed Apr 10 2013 malo <malo> 0.38-6.mga3
+ Revision: 409451
- rebuild for boost 1.53

* Sun Mar 24 2013 colin <colin> 0.38-5.mga3
+ Revision: 404859
- Add systemd requires and general post/pre fixes (mga#9302)

* Mon Jan 14 2013 luigiwalser <luigiwalser> 0.38-4.mga3
+ Revision: 380333
- add tmpfiles config for /run/gearmand

* Fri Jan 11 2013 umeabot <umeabot> 0.38-3.mga3
+ Revision: 351177
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Dec 20 2012 fwang <fwang> 0.38-2.mga3
+ Revision: 333035
- rebuild for new boost

* Sun Sep 16 2012 fwang <fwang> 0.38-1.mga3
+ Revision: 294288
- new version 0.38

* Fri Sep 07 2012 fwang <fwang> 0.37-1.mga3
+ Revision: 289093
- more Werror disabling
- rediff werror patch
- new version 0.37

* Sun Sep 02 2012 fwang <fwang> 0.36-1.mga3
+ Revision: 287199
- update file list
- drop Werror and correct ldflags usage
- new version 0.36

* Thu Aug 02 2012 spuhler <spuhler> 0.34-1.mga3
+ Revision: 277798
- upgrade to ver. 0.34

* Wed May 30 2012 fwang <fwang> 0.28-2.mga3
+ Revision: 250094
- rebuild for new boost

* Sat Jan 28 2012 fwang <fwang> 0.28-1.mga2
+ Revision: 202422
- new version 0.28

* Sun Jan 22 2012 kamil <kamil> 0.27-2.mga2
+ Revision: 199451
- rebuild against new tokyocabinet-1.4.47
- clean .spec

* Fri Jan 13 2012 wally <wally> 0.27-1.mga2
+ Revision: 195802
- temporary disable tests as hostileworker_test fails on i586
- disable 64bit build on i586 arch
- fix file list
+ fwang <fwang>
- add more br
- new version 0.27
- fix br
- rebuild for new libmemcached
+ tv <tv>
- new release

* Sun Jul 17 2011 fwang <fwang> 0.14-3.mga2
+ Revision: 125237
- rebuild for new libmemcached

* Sat Feb 05 2011 spuhler <spuhler> 0.14-2.mga1
+ Revision: 47566
- removed buildroot definition from .spec
  removed the if mdkversion lines
- imported package gearmand


* Sun Oct 10 2010 Oden Eriksson <oeriksson@mandriva.com> 0.14-2mdv2011.0
+ Revision: 584643
- rebuilt against new libmemcached

* Mon Aug 09 2010 Oden Eriksson <oeriksson@mandriva.com> 0.14-1mdv2011.0
+ Revision: 568083
- 0.14

* Sat Apr 24 2010 Funda Wang <fwang@mandriva.org> 0.13-2mdv2010.1
+ Revision: 538457
- rebuild for libmemcached 0.40

* Thu Apr 08 2010 Oden Eriksson <oeriksson@mandriva.com> 0.13-1mdv2010.1
+ Revision: 532893
- 0.13

* Tue Feb 23 2010 Oden Eriksson <oeriksson@mandriva.com> 0.12-1mdv2010.1
+ Revision: 510163
- 0.12

* Wed Jan 13 2010 Oden Eriksson <oeriksson@mandriva.com> 0.11-2mdv2010.1
+ Revision: 490981
- rebuilt against new libmemcached.so.4

* Wed Dec 09 2009 Oden Eriksson <oeriksson@mandriva.com> 0.11-1mdv2010.1
+ Revision: 475232
- whoops! the major bumped to 3
- 0.11

* Fri Oct 02 2009 Oden Eriksson <oeriksson@mandriva.com> 0.10-1mdv2010.0
+ Revision: 452628
- 0.10
- new major (2)
- fix deps
- new sub package (server libs)

* Fri Jul 31 2009 Frederik Himpe <fhimpe@mandriva.org> 0.9-1mdv2010.0
+ Revision: 405218
- update to new version 0.9

* Sat Jul 11 2009 Oden Eriksson <oeriksson@mandriva.com> 0.8-1mdv2010.0
+ Revision: 394825
- 0.8

* Sat Jul 11 2009 Oden Eriksson <oeriksson@mandriva.com> 0.7-2mdv2010.0
+ Revision: 394778
- rebuilt against new libmemcached

* Thu Jul 02 2009 Oden Eriksson <oeriksson@mandriva.com> 0.7-1mdv2010.0
+ Revision: 391818
- fix deps
- import gearmand


* Wed Jul 01 2009 Oden Eriksson <oeriksson@mandriva.com> 0.7-1mdv2009.0
- initial Mandriva package
